@@ -84,8 +84,19 @@ func (inode *Inode) RecfileFields() []recfile.Field {
 	}
 }
 
-func inodeFromFile(fd *os.File) (*Inode, error) {
-	var fi os.FileInfo
+func inodeFromFileStat(fi os.FileInfo, stat unix.Stat_t) *Inode {
+	ctimeSec, ctimeNsec := stat.Ctim.Unix()
+	mtimeSec := fi.ModTime().Unix()
+	mtimeNsec := fi.ModTime().UnixNano()
+	return &Inode{
+		Size:     fi.Size(),
+		InodeNum: uint64(stat.Ino),
+		CtimeSec: ctimeSec, CtimeNsec: ctimeNsec,
+		MtimeSec: mtimeSec, MtimeNsec: mtimeNsec,
+	}
+}
+
+func inodeFromFileByFd(fd *os.File) (*Inode, error) {
 	fi, err := fd.Stat()
 	if err != nil {
 		return nil, err
@@ -95,15 +106,20 @@ func inodeFromFile(fd *os.File) (*Inode, error) {
 	if err != nil {
 		return nil, err
 	}
-	ctimeSec, ctimeNsec := stat.Ctim.Unix()
-	mtimeSec := fi.ModTime().Unix()
-	mtimeNsec := fi.ModTime().UnixNano()
-	return &Inode{
-		Size:     fi.Size(),
-		InodeNum: uint64(stat.Ino),
-		CtimeSec: ctimeSec, CtimeNsec: ctimeNsec,
-		MtimeSec: mtimeSec, MtimeNsec: mtimeNsec,
-	}, nil
+	return inodeFromFileStat(fi, stat), nil
+}
+
+func inodeFromFileByPath(p string) (*Inode, error) {
+	fi, err := os.Stat(p)
+	if err != nil {
+		return nil, err
+	}
+	var stat unix.Stat_t
+	err = unix.Stat(p, &stat)
+	if err != nil {
+		return nil, err
+	}
+	return inodeFromFileStat(fi, stat), nil
 }
 
 func inodeFromRec(m map[string]string) (*Inode, error) {
