@@ -102,7 +102,7 @@ func init() {
 }
 
 func erasedStatus(s, end string) string {
-	if NoProgress {
+	if NoProgress || NoColor {
 		return s + end
 	}
 	return s + KeyEraseLine + end
