@@ -24,7 +24,7 @@ import (
 )
 
 func tempfile(dir, prefix string) (*os.File, error) {
-	tmp, err := os.CreateTemp(dir, prefix)
+	tmp, err := os.CreateTemp(dir, TmpPrefix+prefix+".")
 	if err != nil {
 		return nil, err
 	}
